@@ -1,15 +1,18 @@
 import os
 
+from vellum.api_resources.search import Search
 from vellum.api_resources import Generate
 from vellum.api_resources.completion_actuals import SubmitCompletionActuals
-from vellum.api_resources.types import CompletionActual, GenerateRequest
+from vellum.api_resources.types import CompletionActual, GenerateRequest, SearchOptions
 
 api_key = os.environ.get("VELLUM_API_KEY")
 
 __all__ = [
+    "CompletionActual",
     "Generate",
     "GenerateRequest",
+    "Search",
+    "SearchOptions",
     "SubmitCompletionActuals",
-    "CompletionActual",
     "api_key",
 ]
